==> zio-aws-apigatewayv2_2.12-5.17.104.2-sources.jar: zio/aws/apigatewayv2/model/DeleteDomainNameRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDomainNameRequest(domainName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest = {
    import DeleteDomainNameRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
      .builder()
      .domainName(__string.unwrap(domainName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteDomainNameRequest.wrap(buildAwsValue())
}
object DeleteDomainNameRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteDomainNameRequest =
      zio.aws.apigatewayv2.model.DeleteDomainNameRequest(domainName)
    def domainName: __string
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ) extends zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly {
    override val domainName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.domainName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ): zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.12-7.21.15.7-sources.jar: zio/aws/apigatewayv2/model/DeleteDomainNameRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDomainNameRequest(domainName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest = {
    import DeleteDomainNameRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
      .builder()
      .domainName(domainName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteDomainNameRequest.wrap(buildAwsValue())
}
object DeleteDomainNameRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteDomainNameRequest =
      zio.aws.apigatewayv2.model.DeleteDomainNameRequest(domainName)
    def domainName: __string
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ) extends zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly {
    override val domainName: __string = impl.domainName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDomainNameRequest
  ): zio.aws.apigatewayv2.model.DeleteDomainNameRequest.ReadOnly = new Wrapper(
    impl
  )
}
